Presenter<State> class abstract base

Inheritance

Constructors

Presenter(State? _initialState)

Properties

hashCode int
The hash code for this object.
no setterinherited
mounted bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ↔ State
getter/setter pair
stateBroadcastController StreamController<State>
latefinalinherited
stream Stream<State>
no setteroverride

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watchState() Stream<State>

Operators

operator ==(Object other) bool
The equality operator.
inherited