state property

State get state

Implementation

State get state {
  assert(
    _state != null && mounted,
    'Trying getting state when state null or during markNeedsBuild',
  );

  return _state!;
}
set state (State updatedState)

Implementation

set state(State updatedState) {
  assert(
    !stateBroadcastController.isClosed && mounted,
    'Trying to update state when Stream is closed and when presenter is mounted',
  );

  _state = updatedState;
  stateBroadcastController.add(updatedState);
}