Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialState → State
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → State
-
no setter
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
watchState(
) → Stream< State>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited